@@ -5,6 +5,8 @@
 #
 # SPDX-License-Identifier: MIT
 
+from tuxrun.exceptions import InvalidArgument
+
 
 def subclasses(cls):
     return set(cls.__subclasses__()).union(
@@ -21,13 +23,13 @@ class Device:
 
             if subclass.name == name:
                 return subclass
-        raise NotImplementedError(f"Unknown device {name}")
+        raise InvalidArgument(f"Unknown device {name}")
 
     @classmethod
     def list(cls):
         return sorted([s.name for s in subclasses(cls) if s.name])
 
-    def validate(self, options):
+    def validate(self, **kwargs):
         raise NotImplementedError()  # pragma: no cover
 
     def definition(self, **kwargs):
